==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dcc-update-plugin/translations/update_lt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt">
<context>
    <name>CheckUpdate</name>
    <message>
        <source>Last check: </source>
        <translation>Paskutinis tikrinimas: </translation>
    </message>
</context>
<context>
    <name>QuitTestingChannelDialog</name>
    <message>
        <source>If you exit the beta program, you will no longer receive beta updates.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateDisable</name>
    <message>
        <source>The system updates are disabled. Please contact your administrator for help</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your system is not activated, and it failed to connect to update services</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateHistoryDialog</name>
    <message>
        <source>Update History</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No update history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System Updates</source>
        <translation>Sistemos atnaujinimai</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Saugumo atnaujinimai</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and security updates</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Pristato saugumo atnaujinimus</translation>
    </message>
    <message>
        <source>Installation date:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateList</name>
    <message>
        <source>View Details</source>
        <translation>Rodyti išsamiau</translation>
    </message>
    <message>
        <source>Updates:</source>
        <translation>Atnaujinimai:</translation>
    </message>
    <message>
        <source>Release time:</source>
        <translation>Išleidimo laikas:</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogHelper</name>
    <message>
        <source>NONE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>LOW</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>MEDIUM</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HIGH</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>CRITICAL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>critical-risk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>high-risk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>medium-risk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>low-risk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This update fixes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>vulnerabilities</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>vulnerability</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 of %2 %3</source>
        <translation type="unfinished"/>
        <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
    </message>
    <message>
        <source>, </source>
        <translation>, </translation>
        <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
    </message>
    <message>
        <source>for more details, please visit </source>
        <translation>išsamesnei informacijai apsilankykite </translation>
        <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Checking for updates, please wait…</source>
        <translation>Ieškoma atnaujinimų, palaukite…</translation>
    </message>
    <message>
        <source>Your system is up to date</source>
        <translation>Jūsų sistema yra atnaujinta</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Nežinoma klaida</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please free up %1 disk space first.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dependency error, failed to detect the updates</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please check your network and try again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading updates failed. Please check your network and try again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Insufficient disk space</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG klaida</translation>
    </message>
    <message>
        <source>File missing</source>
        <translation>Trūksta failo</translation>
    </message>
    <message>
        <source>Service connection is abnormal, please check the network and try again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The repository source configuration is not valid, please check and try again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check Again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To use this software, you must accept the %1 that accompanies software updates.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn on the switches under Update Content to get better experiences</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateSetting</name>
    <message>
        <source>Smart Mirror Switch</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Function Updates</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Saugumo atnaujinimai</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Pristato saugumo atnaujinimus</translation>
    </message>
    <message>
        <source>Third-party Updates</source>
        <translation>Trečiųjų šalių atnaujinimai</translation>
    </message>
    <message>
        <source>Delivers  updates for additional repository sources</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Limit Speed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Limit Setting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Auto Download</source>
        <translation>Automatinis atsiuntimas</translation>
    </message>
    <message>
        <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Download when Inactive</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start at</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>End at</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>Išplėstiniai nustatymai</translation>
    </message>
    <message>
        <source>Updates Notification</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clear Package Cache</source>
        <translation>Išvalyti paketų podėlį</translation>
    </message>
    <message>
        <source>Update History</source>
        <translation>Atnaujinimų istorija</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Rodyti</translation>
    </message>
    <message>
        <source>Join Internal Testing Channel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Click here to complete the application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Expand</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>System Updates</source>
        <translation>Sistemos atnaujinimai</translation>
    </message>
    <message>
        <source>Fixed some known bugs and security vulnerabilities</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Saugumo atnaujinimai</translation>
    </message>
    <message>
        <source>Third-party Repositories</source>
        <translation>Trečiųjų šalių saugyklos</translation>
    </message>
</context>
<context>
    <name>update</name>
    <message>
        <source>System Update</source>
        <translation>Systemos atnaujinimas</translation>
    </message>
    <message>
        <source>System update and upgrade</source>
        <translation>Sistemos atnaujinimas ir naujinimas</translation>
    </message>
</context>
<context>
    <name>updateMain</name>
    <message>
        <source>Update Settings</source>
        <translation>Atnaujinimų nustatymai</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Įdiegama</translation>
    </message>
    <message>
        <source>Update download completed</source>
        <translation>Atnaujinimo atsiuntimas užbaigtas</translation>
    </message>
    <message>
        <source>Install updates</source>
        <translation>Įdiegti atnaujinimus</translation>
    </message>
    <message>
        <source>Update size: </source>
        <translation>Atnaujinimo dydis: </translation>
    </message>
    <message>
        <source>Update download failed</source>
        <translation>Nepavyko atsisiųsti atnaujinimo</translation>
    </message>
    <message>
        <source>Downloading updates...</source>
        <translation>Atsiunčiami atnaujinimai...</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Atsiunčiama</translation>
    </message>
    <message>
        <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reboot now</source>
        <translation>Paleisti iš naujo dabar</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Atsisiųsti</translation>
    </message>
    <message>
        <source>Installing updates...</source>
        <translation>Įdiegiami atnaujinimai...</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Bandyti dar kartą</translation>
    </message>
    <message>
        <source>Continue Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Updates Available</source>
        <translation>Yra prieinami atnaujinimai</translation>
    </message>
    <message>
        <source>Installation update failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Backing up in progress...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Backing up in progress</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Backup failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update installation successful</source>
        <translation>Atnaujinimas sėkmingai įdiegtas</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Try Again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The battery capacity is lower than 60%. To get successful updates, please plug in.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.13.tar.xz: BUILD/src/dcc-update-plugin/translations/update_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>CheckUpdate</name>
    <message>
        <source>Last check: </source>
        <translation>Paskutinis tikrinimas: </translation>
    </message>
</context>
<context>
    <name>QuitTestingChannelDialog</name>
    <message>
        <source>If you exit the beta program, you will no longer receive beta updates.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateHistoryDialog</name>
    <message>
        <source>Update History</source>
        <translation type="unfinished">Atnaujinimų istorija</translation>
    </message>
    <message>
        <source>No update history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System Updates</source>
        <translation>Sistemos atnaujinimai</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Saugumo atnaujinimai</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and security updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Pristato saugumo atnaujinimus</translation>
    </message>
    <message>
        <source>Installation date:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateList</name>
    <message>
        <source>View Details</source>
        <translation>Rodyti išsamiau</translation>
    </message>
    <message>
        <source>Updates:</source>
        <translation>Atnaujinimai:</translation>
    </message>
    <message>
        <source>Release time:</source>
        <translation>Išleidimo laikas:</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateLogHelper</name>
    <message>
        <source>NONE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LOW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MEDIUM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HIGH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CRITICAL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>critical-risk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>high-risk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>medium-risk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>low-risk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This update fixes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>vulnerabilities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>vulnerability</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 of %2 %3</source>
        <translation type="unfinished"></translation>
        <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
    </message>
    <message>
        <source>, </source>
        <translation>, </translation>
        <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
    </message>
    <message>
        <source>for more details, please visit </source>
        <translation>išsamesnei informacijai apsilankykite </translation>
        <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Checking for updates, please wait…</source>
        <translation>Ieškoma atnaujinimų, palaukite…</translation>
    </message>
    <message>
        <source>Your system is up to date</source>
        <translation>Jūsų sistema yra atnaujinta</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Nežinoma klaida</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please free up %1 disk space first.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dependency error, failed to detect the updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please check your network and try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading updates failed. Please check your network and try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insufficient disk space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG klaida</translation>
    </message>
    <message>
        <source>File missing</source>
        <translation>Trūksta failo</translation>
    </message>
    <message>
        <source>Service connection is abnormal, please check the network and try again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The repository source configuration is not valid, please check and try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>To use this software, you must accept the %1 that accompanies software updates.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Turn on the switches under Update Content to get better experiences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your system is not activated, and it failed to connect to update services</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The system updates are disabled. Please contact your administrator for help</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateSelectDialog</name>
    <message>
        <source>The updates have been already downloaded. What do you want to do?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Silent Installation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateSetting</name>
    <message>
        <source>Smart Mirror Switch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Function Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Saugumo atnaujinimai</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Pristato saugumo atnaujinimus</translation>
    </message>
    <message>
        <source>Third-party Updates</source>
        <translation>Trečiųjų šalių atnaujinimai</translation>
    </message>
    <message>
        <source>Delivers  updates for additional repository sources</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limit Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limit Setting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Download</source>
        <translation>Automatinis atsiuntimas</translation>
    </message>
    <message>
        <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download when Inactive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start at</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End at</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>Išplėstiniai nustatymai</translation>
    </message>
    <message>
        <source>Updates Notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Package Cache</source>
        <translation>Išvalyti paketų podėlį</translation>
    </message>
    <message>
        <source>Update History</source>
        <translation>Atnaujinimų istorija</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Rodyti</translation>
    </message>
    <message>
        <source>Join Internal Testing Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click here to complete the application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only numbers between 1-99999 are allowed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>System Updates</source>
        <translation>Sistemos atnaujinimai</translation>
    </message>
    <message>
        <source>Fixed some known bugs and security vulnerabilities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Saugumo atnaujinimai</translation>
    </message>
    <message>
        <source>Third-party Repositories</source>
        <translation>Trečiųjų šalių saugyklos</translation>
    </message>
</context>
<context>
    <name>update</name>
    <message>
        <source>System Update</source>
        <translation>Systemos atnaujinimas</translation>
    </message>
    <message>
        <source>System update and upgrade</source>
        <translation>Sistemos atnaujinimas ir naujinimas</translation>
    </message>
</context>
<context>
    <name>updateMain</name>
    <message>
        <source>Update Settings</source>
        <translation>Atnaujinimų nustatymai</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Įdiegama</translation>
    </message>
    <message>
        <source>Update download completed</source>
        <translation>Atnaujinimo atsiuntimas užbaigtas</translation>
    </message>
    <message>
        <source>Install updates</source>
        <translation>Įdiegti atnaujinimus</translation>
    </message>
    <message>
        <source>Update size: </source>
        <translation>Atnaujinimo dydis: </translation>
    </message>
    <message>
        <source>Update download failed</source>
        <translation>Nepavyko atsisiųsti atnaujinimo</translation>
    </message>
    <message>
        <source>Downloading updates...</source>
        <translation>Atsiunčiami atnaujinimai...</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Atsiunčiama</translation>
    </message>
    <message>
        <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reboot now</source>
        <translation>Paleisti iš naujo dabar</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Atsisiųsti</translation>
    </message>
    <message>
        <source>Installing updates...</source>
        <translation>Įdiegiami atnaujinimai...</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Bandyti dar kartą</translation>
    </message>
    <message>
        <source>Continue Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Updates Available</source>
        <translation>Yra prieinami atnaujinimai</translation>
    </message>
    <message>
        <source>Installation update failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backing up in progress...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backing up in progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update installation successful</source>
        <translation>Atnaujinimas sėkmingai įdiegtas</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The battery capacity is lower than 60%. To get successful updates, please plug in.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
